Struct cargo_workflows::args::InitCommand
source · pub struct InitCommand;Trait Implementations
sourceimpl Args for InitCommand
impl Args for InitCommand
sourcefn group_id() -> Option<Id>
fn group_id() -> Option<Id>
Report the [
ArgGroup::id][crate::ArgGroup::id] for this set of argumentssourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
sourceimpl Clone for InitCommand
impl Clone for InitCommand
sourcefn clone(&self) -> InitCommand
fn clone(&self) -> InitCommand
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for InitCommand
impl Debug for InitCommand
sourceimpl FromArgMatches for InitCommand
impl FromArgMatches for InitCommand
sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches ) -> Result<Self, Error>
sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches ) -> Result<(), Error>
Assign values from
ArgMatches to self.sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches ) -> Result<(), Error>
Assign values from
ArgMatches to self.sourceimpl Hash for InitCommand
impl Hash for InitCommand
sourceimpl Ord for InitCommand
impl Ord for InitCommand
sourcefn cmp(&self, other: &InitCommand) -> Ordering
fn cmp(&self, other: &InitCommand) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq<InitCommand> for InitCommand
impl PartialEq<InitCommand> for InitCommand
sourcefn eq(&self, other: &InitCommand) -> bool
fn eq(&self, other: &InitCommand) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd<InitCommand> for InitCommand
impl PartialOrd<InitCommand> for InitCommand
sourcefn partial_cmp(&self, other: &InitCommand) -> Option<Ordering>
fn partial_cmp(&self, other: &InitCommand) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for InitCommand
impl StructuralEq for InitCommand
impl StructuralPartialEq for InitCommand